---
title: <span class="badge object-type-scalar"></span> DanishKrone
---
# <span class="badge object-type-scalar"></span> DanishKrone

Currency: Danish Krone (kr)

## Definition

```python
# Currency: Danish Krone (kr)
DanishKrone: typing.Literal["currencyDKK"] = "currencyDKK"
```
